@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 import proto  # type: ignore
@@ -1133,7 +1135,30 @@ class BatchTranslateMetadata(proto.Message):
     """
 
     class State(proto.Enum):
-        r"""State of the job."""
+        r"""State of the job.
+
+        Values:
+            STATE_UNSPECIFIED (0):
+                Invalid.
+            RUNNING (1):
+                Request is being processed.
+            SUCCEEDED (2):
+                The batch is processed, and at least one item
+                was successfully processed.
+            FAILED (3):
+                The batch is done and no item was
+                successfully processed.
+            CANCELLING (4):
+                Request is in the process of being canceled
+                after caller invoked
+                longrunning.Operations.CancelOperation on the
+                request id.
+            CANCELLED (5):
+                The batch is done after the user has called
+                the longrunning.Operations.CancelOperation. Any
+                records processed before the cancel command are
+                output as specified in the request.
+        """
         STATE_UNSPECIFIED = 0
         RUNNING = 1
         SUCCEEDED = 2
@@ -1531,6 +1556,24 @@ class CreateGlossaryMetadata(proto.Message):
     class State(proto.Enum):
         r"""Enumerates the possible states that the creation request can
         be in.
+
+        Values:
+            STATE_UNSPECIFIED (0):
+                Invalid.
+            RUNNING (1):
+                Request is being processed.
+            SUCCEEDED (2):
+                The glossary was successfully created.
+            FAILED (3):
+                Failed to create the glossary.
+            CANCELLING (4):
+                Request is in the process of being canceled
+                after caller invoked
+                longrunning.Operations.CancelOperation on the
+                request id.
+            CANCELLED (5):
+                The glossary creation request was
+                successfully canceled.
         """
         STATE_UNSPECIFIED = 0
         RUNNING = 1
@@ -1575,6 +1618,24 @@ class DeleteGlossaryMetadata(proto.Message):
     class State(proto.Enum):
         r"""Enumerates the possible states that the creation request can
         be in.
+
+        Values:
+            STATE_UNSPECIFIED (0):
+                Invalid.
+            RUNNING (1):
+                Request is being processed.
+            SUCCEEDED (2):
+                The glossary was successfully deleted.
+            FAILED (3):
+                Failed to delete the glossary.
+            CANCELLING (4):
+                Request is in the process of being canceled
+                after caller invoked
+                longrunning.Operations.CancelOperation on the
+                request id.
+            CANCELLED (5):
+                The glossary deletion request was
+                successfully canceled.
         """
         STATE_UNSPECIFIED = 0
         RUNNING = 1
@@ -1980,7 +2041,30 @@ class BatchTranslateDocumentMetadata(proto.Message):
     """
 
     class State(proto.Enum):
-        r"""State of the job."""
+        r"""State of the job.
+
+        Values:
+            STATE_UNSPECIFIED (0):
+                Invalid.
+            RUNNING (1):
+                Request is being processed.
+            SUCCEEDED (2):
+                The batch is processed, and at least one item
+                was successfully processed.
+            FAILED (3):
+                The batch is done and no item was
+                successfully processed.
+            CANCELLING (4):
+                Request is in the process of being canceled
+                after caller invoked
+                longrunning.Operations.CancelOperation on the
+                request id.
+            CANCELLED (5):
+                The batch is done after the user has called
+                the longrunning.Operations.CancelOperation. Any
+                records processed before the cancel command are
+                output as specified in the request.
+        """
         STATE_UNSPECIFIED = 0
         RUNNING = 1
         SUCCEEDED = 2
